PrimitiveGroup

Struct PrimitiveGroup 

pub struct PrimitiveGroup { /* private fields */ }
A group of primitives that can be added to a canvas. This is usally the output of a single widget.

Implementations

Source

impl PrimitiveGroup

pub fn new() -> Self

pub fn clear(&mut self)

pub fn set_scissor_rect(&mut self, scissor_rect: RectI32)

pub fn reset_scissor_rect(&mut self)

pub fn scissor_rect(&self) -> &Option<RectI32>

pub fn set_z_index(&mut self, z_index: u16)

pub fn z_index(&self) -> u16

pub fn add(&mut self, primitive: impl Into<Primitive>)

pub fn add_solid_quad(&mut self, quad: impl Into<SolidQuadPrimitive>)

pub fn add_gradient_quad(&mut self, quad: impl Into<GradientQuadPrimitive>)

pub fn add_solid_mesh(&mut self, mesh: impl Into<SolidMeshPrimitive>)

pub fn add_gradient_mesh(&mut self, mesh: impl Into<GradientMeshPrimitive>)

pub fn add_mesh(&mut self, mesh: MeshPrimitive)

pub fn add_text(&mut self, text: TextPrimitive)

pub fn add_image(&mut self, image: impl Into<ImagePrimitive>)

pub fn add_custom_primitive(&mut self, primitive: CustomPrimitive)

pub fn add_solid_quad_batch( &mut self, quads: impl IntoIterator<Item = impl Into<SolidQuadPrimitive>>, )

pub fn add_gradient_quad_batch( &mut self, quads: impl IntoIterator<Item = impl Into<GradientQuadPrimitive>>, )

pub fn add_text_batch<'a>( &mut self, buffers: impl IntoIterator<Item = TextPrimitive>, )

pub fn add_solid_mesh_batch( &mut self, meshes: impl IntoIterator<Item = SolidMeshPrimitive>, )

pub fn add_gradient_mesh_batch( &mut self, meshes: impl IntoIterator<Item = GradientMeshPrimitive>, )

pub fn add_mesh_batch( &mut self, meshes: impl IntoIterator<Item = MeshPrimitive>, )